@@ -1,28 +1,23 @@
 import datetime
 from datetime import datetime as dtm
+from datetime import timezone, timedelta
 from calendar import monthrange
 from os.path import commonprefix
 import math
+from doreah.settings import get_settings
 
 
-FIRST_SCROBBLE = int(datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc).timestamp())
+OFFSET = get_settings("TIMEZONE")
+TIMEZONE = timezone(timedelta(hours=OFFSET))
+UTC = datetime.timezone.utc
+
+FIRST_SCROBBLE = int(datetime.datetime.utcnow().replace(tzinfo=UTC).timestamp())
 
 def register_scrobbletime(timestamp):
 	global FIRST_SCROBBLE
 	if timestamp < FIRST_SCROBBLE:
 		FIRST_SCROBBLE = int(timestamp)
 
-def start_of_scrobbling():
-	global FIRST_SCROBBLE
-	f = datetime.datetime.utcfromtimestamp(FIRST_SCROBBLE)
-	return [f.year]
-
-def end_of_scrobbling():
-	global FIRST_SCROBBLE
-	f = datetime.datetime.now()
-	return [f.year]
-
-
 
 
 
@@ -62,7 +57,7 @@ class MRangeDescriptor:
 		}
 
 	def uri(self):
-		return "&".join(k + "=" + self.urikeys[k] for k in self.urikeys)
+		return "&".join(k + "=" + self.urikeys()[k] for k in self.urikeys())
 
 	def unlimited(self):
 		return False
@@ -178,10 +173,10 @@ class MTime(MRangeDescriptor):
 
 	def first_stamp(self):
 		day = self.first_day().dateobject
-		return int(datetime.datetime.combine(day,datetime.time(tzinfo=datetime.timezone.utc)).timestamp())
+		return int(datetime.datetime.combine(day,datetime.time(tzinfo=TIMEZONE)).timestamp())
 	def last_stamp(self):
 		day = self.last_day().dateobject + datetime.timedelta(days=1)
-		return int(datetime.datetime.combine(day,datetime.time(tzinfo=datetime.timezone.utc)).timestamp() - 1)
+		return int(datetime.datetime.combine(day,datetime.time(tzinfo=TIMEZONE)).timestamp() - 1)
 
 	# next range of equal length (not exactly same amount of days, but same precision level)
 	def next(self,step=1):
@@ -209,26 +204,17 @@ class MTime(MRangeDescriptor):
 # a range that is exactly one christian week (starting on sunday)
 class MTimeWeek(MRangeDescriptor):
 	def __init__(self,year=None,week=None):
-		self.year = year
-		self.week = week
 
-		# assume the first day of the first week of this year is 1/1
-		firstday = datetime.date(year,1,1)
-		y,w,d = firstday.chrcalendar()
-		if y == self.year:
-			firstday -= datetime.timedelta(days=(d-1))
-		else:
-			firstday += datetime.timedelta(days=8-d)
-		# now we know the real first day, add the weeks we need
-		firstday = firstday + datetime.timedelta(days=7*(week-1))
-		lastday = firstday + datetime.timedelta(days=6)
-		# turn them into local overwritten date objects
-		self.firstday = datetime.date(firstday.year,firstday.month,firstday.day)
-		self.lastday = datetime.date(lastday.year,lastday.month,lastday.day)
-		# now check if we're still in the same year
+		thisisoyear_firstday = datetime.date.fromchrcalendar(year,1,1)
+		self.firstday = thisisoyear_firstday + datetime.timedelta(days=7*(week-1))
+		# do this so we can construct the week with overflow (eg 2020/-3)
+
+		self.lastday = self.firstday + datetime.timedelta(days=6)
+
+		# now get the actual year and week number (in case of overflow)
 		y,w,_ = self.firstday.chrcalendar()
-		self.year,self.week = y,w
-		# firstday and lastday are already correct
+		self.year,self.week,_ = self.firstday.chrcalendar()
+
 
 
 	def __str__(self):
@@ -379,18 +365,18 @@ y = MTime(2020)
 
 
 def today():
-	tod = datetime.datetime.utcnow()
+	tod = datetime.datetime.now(tz=TIMEZONE)
 	return MTime(tod.year,tod.month,tod.day)
 def thisweek():
-	tod = datetime.datetime.utcnow()
+	tod = datetime.datetime.now(tz=TIMEZONE)
 	tod = datetime.date(tod.year,tod.month,tod.day)
 	y,w,_ = tod.chrcalendar()
 	return MTimeWeek(y,w)
 def thismonth():
-	tod = datetime.datetime.utcnow()
+	tod = datetime.datetime.now(tz=TIMEZONE)
 	return MTime(tod.year,tod.month)
 def thisyear():
-	tod = datetime.datetime.utcnow()
+	tod = datetime.datetime.now(tz=TIMEZONE)
 	return MTime(tod.year)
 def alltime():
 	return MRange(None,None)
@@ -545,7 +531,7 @@ def timestamp_desc(t,short=False):
 
 		return timeobject.strftime("%Y")
 	else:
-		timeobject = datetime.datetime.utcfromtimestamp(t)
+		timeobject = datetime.datetime.fromtimestamp(t,tz=TIMEZONE)
 		return timeobject.strftime("%d. %b %Y %I:%M %p")
 
 
@@ -601,16 +587,16 @@ def delimit_desc(step="month",stepn=1,trail=1):
 
 
 def day_from_timestamp(stamp):
-	dt = datetime.datetime.utcfromtimestamp(stamp)
+	dt = datetime.datetime.fromtimestamp(stamp,tz=TIMEZONE)
 	return MTime(dt.year,dt.month,dt.day)
 def month_from_timestamp(stamp):
-	dt = datetime.datetime.utcfromtimestamp(stamp)
+	dt = datetime.datetime.fromtimestamp(stamp,tz=TIMEZONE)
 	return MTime(dt.year,dt.month)
 def year_from_timestamp(stamp):
-	dt = datetime.datetime.utcfromtimestamp(stamp)
+	dt = datetime.datetime.fromtimestamp(stamp,tz=TIMEZONE)
 	return MTime(dt.year)
 def week_from_timestamp(stamp):
-	dt = datetime.datetime.utcfromtimestamp(stamp)
+	dt = datetime.datetime.fromtimestamp(stamp,tz=TIMEZONE)
 	d = datetime.date(dt.year,dt.month,dt.day)
 	y,w,_ = d.chrcalendar()
 	return MTimeWeek(y,w)
